#!/bin/sh

set -e

########################################
#       Checking dialog avaible.       #
########################################

if which dialog; then
    echo "dialog is avaible!"
else 
    echo "dialog is not avaible! Install it, please." ;
    exit 1;
fi ;

########################################
#      Code for dialog-interface.      #
########################################

res="/tmp/$$.tmp"

if dialog --menu "What would you like?" 15 55 5 \
  1 "Check engine's availability." \
  2 "Check dependencies." \
  3 "Prepare build environment." \
  4 "Build engine from scratch." \
  5 "Update engine." \
  6 "Help." \
  7 "Exit." \
  2> "$res";
then
  clear
  var="$(cat "$res")"
  case "$var" in
  
  ########################################
  
    1) echo "Checking k8vavoom!" \
    && FILE="/usr/share/k8vavoom"
if [ -d "$FILE" ]; then
    echo "k8vavoom is avaible!"
else 
    echo "k8vavoom is not avaible!" ;
    exit 0;
fi ;;
    
    ########################################
    
    2) echo "Checking dependencies for k8vavoom!"

if pkg-config --exists opengl; then
    echo "OpenGL is present.";
else
    echo "opengl not installed!";
    MYLIST="$MYLIST opengl"
fi

#########
# SDL2. #
#########

if pkg-config --exists sdl2; then
    echo "SDL2 is present.";
else
    echo "sdl2 not installed!";
    MYLIST="$MYLIST sdl2"
fi

###########
# OpenAl. #
###########

if pkg-config --exists openal; then
    echo "OpenAl is present.";
else
    echo "openal not installed!";
    MYLIST="$MYLIST openal"
fi
########
# Git. #
########

if command -v git; then
    echo "Git is present."
else
    echo "Git not installed!";
    MYLIST="$MYLIST git"
fi

##########
# Cmake. #
##########

if command -v cmake; then
    echo "Cmake is present."
else
    echo "Cmake not installed!";
    MYLIST="$MYLIST cmake"
fi

###############
# PKG-Config. #
###############

if command -v pkg-config; then
    echo "PKG-Config is present."
else
    echo "PKG-Config not installed!";
    MYLIST="$MYLIST pkg-config"
fi

#########
# Sudo. #
#########

if command -v sudo; then
    echo "Sudo is present."
else
    echo "Sudo not installed!";
    MYLIST="$MYLIST sudo"
fi

if [ -n "$MYLIST" ]; then
    echo "Please, install this packages: $MYLIST";
    exit 1;
fi

echo "All dependencies installed! Good, we are working on." ;;
    
    ########################################
    
    3) echo "Preparing build environment!" \
     && FILE="$HOME/build_k8vavoom"
if [ -d "$FILE" ]; then
    echo "Build directory is avaible!"
else 
    echo "Build directory is not avaible! Making..." ;
        mkdir "$HOME/build_k8vavoom" ;
    echo "Directory maked!";
fi

    echo "k8vavoom sources is not avaible! Downloading...";
        cd "$HOME/build_k8vavoom" ;
        git clone https://repo.or.cz/k8vavoom.git ;
    echo "Done.";
    
  ;;

    ########################################

    4) # Environment to building.
	echo "Build directory."
		cd $HOME/build_k8vavoom
		mkdir $HOME/build_k8vavoom/build
		cd build
	echo "Done."


# Building.

    echo "Configuration and building!"
        cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo -DENABLE_SERVER=ON -DCMAKE_INSTALL_PREFIX=/usr -DENABLE_VCCRUN=OFF -DARCH_LINUX_SPECIAL=$ARCH_LINUX_SPECIAL "$HOME/build_k8vavoom/k8vavoom" ;
        make -j$(nproc) ;
    echo "Done.";

# Echoing the echo.
    echo "Have a nice game! :)";
    echo "You'd better create '~/.k8vavoom/iwads' directory and put at least one";
    echo "IWAD file there to play a game. You can specify a game name with the";
    echo "corresponding command line switch, e.g. -doom, -doom2, -tnt, etc.";
        exit 0 ;;
    
    ########################################
    
    5) echo "Checking sources!"

FILE="$HOME/build_k8vavoom/k8vavoom"
if [ -d "$FILE" ]; then
    echo "k8vavoom sources is avaible! Updating..." ;
        cd "$HOME/build_k8vavoom/k8vavoom" ;
            git pull ;
    echo "Sources is updated.";
    
# Preparing building environment.

    echo "Preparing build catalog!" ;
        cd "$HOME/build_k8vavoom" ;
        rm -R build ;
        mkdir build ;
        cd build ;
    echo "Done.";


# Building.

    echo "Configuration and building!";
        cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo -DENABLE_SERVER=ON -DCMAKE_INSTALL_PREFIX=/usr -DENABLE_VCCRUN=OFF -DARCH_LINUX_SPECIAL=$ARCH_LINUX_SPECIAL "$HOME/build_k8vavoom/k8vavoom" ;
        make -j$(nproc);
    echo "Done.";

# Installing.

    echo "Installing update!";
        sudo make install
    echo "k8vavoom updated." 
    exit 0 
else
    echo "Hey, you without source files!"
    exit 1 
    fi ;;
    
    ########################################
    
    6) echo "Hello! This a build/update script for k8vavoom!"
       echo "This script will help you build and install an engine, such as k8vavoom."
       
       echo "First of all, go through the first three points to prepare"
       echo "a platform for you to compile the engine."
       
       echo "Once all the dependencies are installed, and the directories"
       echo "are created and the engine is not installed, choose the fourth item."
       
       echo "If you already have the engine installed, select the fifth item from the list"
       echo "to update engine."
       echo "Script writed by TerminalHash with little help from friends."
       echo "							version vDialog_1.1"
 ;;
    
    ########################################
    
    7) echo "Finishing the script execution." && exit 0 ;;
    
    ########################################
    
    *) echo "What you doing?" ;;
  esac
else
  clear
  echo "Goodbye!"
fi

rm -f "$res"
